Table of Featurizers — matminer 0.4.6 documentation

# Table of Featurizers

Below, you will find a description of each featurizer, listed in tables grouped by module.

## bandstructure

### Features derived from a material’s electronic bandstructure.

(matminer.featurizers.bandstructure)

Name | Description
--- | ---
`BranchPointEnergy` | Branch point energy and absolute band edge position. [more]
`BandFeaturizer` | Featurizes a pymatgen band structure object. [more]

## base

### Parent classes and meta-featurizers.

(matminer.featurizers.base)

Name | Description
--- | ---
`MultipleFeaturizer` | Class to run multiple featurizers on the same input data. [more]
`StackedFeaturizer` | Use the output of a machine learning model as features [more]
`BaseFeaturizer` | Abstract class to calculate features from raw materials input data [more]

## composition

### Features based on a material’s composition.

(matminer.featurizers.composition)

Name | Description
--- | ---
`ElementProperty` | Class to calculate elemental property attributes. [more]
`OxidationStates` | Statistics about the oxidation states for each specie. [more]
`AtomicOrbitals` | Determine HOMO/LUMO features based on a composition. [more]
`BandCenter` | Estimation of absolute position of band center using electronegativity. [more]
`ElectronegativityDiff` | Features from electronegativity differences between anions and cations. [more]
`ElectronAffinity` | Calculate average electron affinity times formal charge of anion elements. [more]
`Stoichiometry` | Calculate norms of stoichiometric attributes. [more]
`ValenceOrbital` | Attributes of valence orbital shells [more]
`IonProperty` | Ionic property attributes. Similar to ElementProperty. [more]
`ElementFraction` | Class to calculate the atomic fraction of each element in a composition. [more]
`TMetalFraction` | Class to calculate fraction of magnetic transition metals in a composition. [more]
`CohesiveEnergy` | Cohesive energy per atom using elemental cohesive energies and [more]
`Miedema` | Formation enthalpies of intermetallic compounds, from Miedema et al. [more]
`YangSolidSolution` | Mixing thermochemistry and size mismatch terms of Yang and Zhang (2012) [more]
`AtomicPackingEfficiency` | Packing efficiency based on a geometric theory of the amorphous packing [more]

## dos

### Features based on a material’s electronic density of states.

(matminer.featurizers.dos)

Name | Description
--- | ---
`DOSFeaturizer` | Significant character and contribution of the density of state from a [more]
`DopingFermi` | The fermi level (w.r.t. selected reference energy) associated with a [more]
`Hybridization` | quantify s/p/d/f orbital character and their hybridizations at band edges [more]

## function

### Classes for expanding sets of features calculated with other featurizers.

(matminer.featurizers.function)

Name | Description
--- | ---
`FunctionFeaturizer` | Features from functions applied to existing features, e.g. “1/x” [more]

## site

### Features from individual sites in a material’s crystal structure.

(matminer.featurizers.site)

Name | Description
--- | ---
`AGNIFingerprints` | Product integral of RDF and Gaussian window function, from Botu et al. [more]
`OPSiteFingerprint` | Local structure order parameters computed from a site’s neighbor env. [more]
`CrystalNNFingerprint` | A local order parameter fingerprint for periodic crystals. [more]
`VoronoiFingerprint` | Voronoi tessellation-based features around target site. [more]
`ChemicalSRO` | Chemical short range ordering, deviation of local site and nominal structure compositions [more]
`GaussianSymmFunc` | Gaussian symmetry function features suggested by Behler et al. [more]
`EwaldSiteEnergy` | Compute site energy from Coulombic interactions [more]
`ChemEnvSiteFingerprint` | Resemblance of given sites to ideal environments [more]
`CoordinationNumber` | Number of first nearest neighbors of a site. [more]
`GeneralizedRadialDistributionFunction` | Compute the general radial distribution function (GRDF) for a site. [more]
`AngularFourierSeries` | Compute the angular Fourier series (AFS), including both angular and radial info [more]
`LocalPropertyDifference` | Differences in elemental properties between site and its neighboring sites. [more]
`BondOrientationalParameter` | Averages of spherical harmonics of local neighbors [more]
`SiteElementalProperty` | Elemental properties of atom on a certain site [more]
`AverageBondLength` | Determines the average bond length between one specific site [more]
`AverageBondAngle` | Determines the average bond angles of a specific site with [more]

## structure

### Generating features based on a material’s crystal structure.

(matminer.featurizers.structure)

Name | Description
--- | ---
`DensityFeatures` | Calculates density and density-like features [more]
`GlobalSymmetryFeatures` | Determines symmetry features, e.g. spacegroup number and crystal system [more]
`Dimensionality` | Returns dimensionality of structure: 1 means linear chains of atoms OR [more]
`RadialDistributionFunction` | Calculate the radial distribution function (RDF) of a crystal structure. [more]
`PartialRadialDistributionFunction` | Compute the partial radial distribution function (PRDF) of an xtal structure [more]
`ElectronicRadialDistributionFunction` | Calculate the inherent electronic radial distribution function (ReDF) [more]
`CoulombMatrix` | Generate the Coulomb matrix, a representation of nuclear coulombic interaction. [more]
`SineCoulombMatrix` | A variant of the Coulomb matrix developed for periodic crystals. [more]
`OrbitalFieldMatrix` | Representation based on the valence shell electrons of neighboring atoms. [more]
`MinimumRelativeDistances` | Determines the relative distance of each site to its closest neighbor. [more]
`SiteStatsFingerprint` | Computes statistics of properties across all sites in a structure. [more]
`EwaldEnergy` | Compute the energy from Coulombic interactions. [more]
`BondFractions` | Compute the fraction of each bond in a structure, based on NearestNeighbors. [more]
`BagofBonds` | Compute a Bag of Bonds vector, as first described by Hansen et al. (2015). [more]
`StructuralHeterogeneity` | Variance in the bond lengths and atomic volumes in a structure [more]
`MaximumPackingEfficiency` | Maximum possible packing efficiency of this structure [more]
`ChemicalOrdering` | How much the ordering of species in the structure differs from random [more]
`StructureComposition` | Features related to the composition of a structure [more]
`XRDPowderPattern` | 1D array representing powder diffraction of a structure as calculated by [more]
`JarvisCFID` | Classical Force-Field Inspired Descriptors (CFID) from Jarvis-ML. [more]